﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using ServiceTestClient.ClientService;


namespace ServiceTestClient
{
    public partial class TestClient : System.Web.UI.Page
    {
        protected int MerchantID
        {
            get
            {
                return Convert.ToInt32(txtMID.Text);
            }
        }


        #region CreateClient
        private void CreateClient(int mid)
        {
            ClientRecord client = new ClientRecord();
            client.MerchantID = MerchantID;
            client.FirstName = "Testing";
            client.LastName = "Service";
            client.CompanyName = "ACHDirect";
            client.Address1 = "500 W Bethany DR";
            client.Address2 = "Suite 200";
            client.City = "Allen";
            client.State = "TX";
            client.PostalCode = "75013";
            client.CountryCode = "01";
            client.PhoneNumber = "333-123-1234";
            client.EmailAddress = "Test@achdirect.com";
            client.FaxNumber = "444-123-1234";
            client.ConsumerID = "123456";
            client.ShiptoFirstName = "Shipping Name";
            client.ShiptoLastName = "Ship Last Name";
            client.ShiptoCompanyName = "Ach Direct";
            client.ShiptoAddress1 = "550 E Bethany Dr";
            client.ShiptoAddress2 = "Suite 500";
            client.ShiptoCity = "Plano";
            client.ShiptoState = "TX";
            client.ShiptoPostalCode = "75642";
            client.ShiptoCountryCode = "01";
            client.ShiptoPhoneNumber = "111-123-1234";
            client.ShiptoFaxNumber = "222-123-1234";

            try
            {
                using (ClientServiceClient proxy = new ClientServiceClient("WSHttpBinding"))
                {
                    int id = proxy.createClient(Authenticate.GetClientAuthTicket(txtID.Text.Trim(), txtKey.Text.Trim()), client);

                    ViewState["ClientID"] = id;
                    btnDeleteClient.Enabled = true;
                    btnUpdateClient.Enabled = true;
                    btnCreatePayment.Enabled = true;
                    btnCreateEC.Enabled = true;
                    txtClientID.Text = id.ToString();
                    txtClientID0.Text = id.ToString();
                    lblMsg.Text += "Created ClientID = " + id.ToString() + "<br>";
                }
            }
            catch (Exception e)
            {
                lblMsg.Text += e.Message + "<br>";
            }
        }
        #endregion

        #region UpdateClient
        private void UpdateClient(int mid)
        {
            ClientRecord client = new ClientRecord();
            client.MerchantID = MerchantID;
            client.FirstName = "TestingUd";
            client.LastName = "ServiceUd";
            client.CompanyName = "ACHDirectYd";
            client.Address1 = "500 W Bethany DRUd";
            client.Address2 = "Suite 200Ud";
            client.City = "AllenUd";
            client.State = "TX";
            client.PostalCode = "75013";
            client.CountryCode = "01";
            client.PhoneNumber = "444-444-4444";
            client.EmailAddress = "Test@achdirect.com";
            client.FaxNumber = "333-333-3333";
            client.Status = ClientStatus.Active;
            client.ConsumerID = "654321";
            client.ShiptoFirstName = "Shipping NameUd";
            client.ShiptoLastName = "Ship Last NameUd";
            client.ShiptoCompanyName = "Ach DirectUd";
            client.ShiptoAddress1 = "550 E Bethany DrUd";
            client.ShiptoAddress2 = "Suite 500Ud";
            client.ShiptoCity = "PlanoUd";
            client.ShiptoState = "TX";
            client.ShiptoPostalCode = "75642";
            client.ShiptoCountryCode = "01";
            client.ShiptoPhoneNumber = "444-444-4444";
            client.ShiptoFaxNumber = "333-333-3333";
            client.ClientID = Convert.ToInt32(ViewState["ClientID"]);

            try
            {
                using (ClientServiceClient proxy = new ClientServiceClient("WSHttpBinding"))
                {
                    int id = proxy.updateClient(Authenticate.GetClientAuthTicket(txtID.Text.Trim(), txtKey.Text.Trim()), client);
                    lblMsg.Text += "Updated ClientID = " + id.ToString() + "<br>";
                }
            }
            catch (Exception e)
            {
                lblMsg.Text += e.Message + "<br>";
            }
        }
        #endregion

        #region CreateCCPayment
        private void CreateCCPayment(int ClientID, int mid)
        {
            PaymentMethod payment = new PaymentMethod();
            payment.AcctHolderName = "TestGuy";
            payment.CcCardNumber = "4111111111111111";
            payment.CcExpirationDate = "201506";
            payment.CcCardType = CcCardType.VISA;
            payment.Note = "Created by Mbhattar";
            payment.ClientID = ClientID;
            payment.MerchantID = mid;

            try
            {
                using (ClientServiceClient proxy = new ClientServiceClient("WSHttpBinding"))
                {
                    int id = proxy.createPaymentMethod(Authenticate.GetClientAuthTicket(txtID.Text.Trim(), txtKey.Text.Trim()), payment);
                    ViewState["PaymentMethodID"] = id;
                    btnDeletePayment.Enabled = true;
                    btnUpdatePayment.Enabled = true;
                    txtPaymentID.Text = id.ToString();
                    lblMsg.Text += "Created CC PaymentMethodID: " + id.ToString() + "<br>";
                }
            }
            catch (Exception e)
            {
                lblMsg.Text += e.Message + "<br>";
            }
        }
        #endregion

        #region UpdateCCPayment
        private void UpdateCCPayment(int ClientID, int mid)
        {
            PaymentMethod payment = new PaymentMethod();
            payment.AcctHolderName = "TestGuyUpdated";
            payment.CcExpirationDate = "201111";
            payment.IsDefault = true;
            payment.CcProcurementCard = true;
            payment.Note = "Updated by Li";
            payment.ClientID = ClientID;
            payment.MerchantID = mid;
            payment.PaymentMethodID = Convert.ToInt32(ViewState["PaymentMethodID"]);

            try
            {
                using (ClientServiceClient proxy = new ClientServiceClient("WSHttpBinding"))
                {
                    int id = proxy.updatePaymentMethod(Authenticate.GetClientAuthTicket(txtID.Text.Trim(), txtKey.Text.Trim()), payment);
                    lblMsg.Text += "Updated CC PaymentMethodID: " + id.ToString() + "<br>";
                }
            }
            catch (Exception e)
            {
                lblMsg.Text += e.Message + "<br>";
            }
        }
        #endregion

        #region CreateECPayment
        private void CreateECPayment(int ClientID, int mid)
        {
            PaymentMethod payment = new PaymentMethod();
            payment.AcctHolderName = "li Zhou";
            payment.EcAccountNumber = "1234567";
            payment.EcAccountTRN = "211170101";
            payment.EcAccountType = EcAccountType.SAVINGS;
            payment.ClientID = ClientID;
            payment.MerchantID = mid;

            try
            {
                using (ClientServiceClient proxy = new ClientServiceClient("WSHttpBinding"))
                {
                    int id = proxy.createPaymentMethod(Authenticate.GetClientAuthTicket(txtID.Text.Trim(), txtKey.Text.Trim()), payment);
                    ViewState["PaymentMethodID"] = id;
                    btnDeletePayment0.Enabled = true;
                    btnUpdateEc.Enabled = true;
                    txtPaymentID.Text = id.ToString();
                    lblMsg.Text += "Created EC PaymentMethodID: " + id.ToString() + "<br>";
                }
            }
            catch (Exception e)
            {
                lblMsg.Text += e.Message + "<br>";
            }
        }
        #endregion

        #region UpdateECPayment
        private void UpdateECPayment(int ClientID, int mid)
        {
            PaymentMethod payment = new PaymentMethod();

            payment.AcctHolderName = "Li Update";
            payment.Note = "Updated by Li";
            payment.IsDefault = true;
            payment.ClientID = ClientID;
            payment.MerchantID = mid;
            payment.PaymentMethodID = Convert.ToInt32(ViewState["PaymentMethodID"]);

            try
            {

                using (ClientServiceClient proxy = new ClientServiceClient("WSHttpBinding"))
                {
                    int id = proxy.updatePaymentMethod(Authenticate.GetClientAuthTicket(txtID.Text.Trim(), txtKey.Text.Trim()), payment);
                    lblMsg.Text += "Updated EC PaymentMethodID: " + id.ToString() + "<br>";
                }
            }
            catch (Exception e)
            {
                lblMsg.Text += e.Message + "<br>";
            }
        }
        #endregion

        #region DeletePayment
        private void DeletePayment(int PaymentMethodID, int mid)
        {
            try
            {
                using (ClientServiceClient proxy = new ClientServiceClient("WSHttpBinding"))
                {
                    int id = proxy.deletePaymentMethod(Authenticate.GetClientAuthTicket(txtID.Text.Trim(), txtKey.Text.Trim()), mid, PaymentMethodID);
                    lblMsg.Text += "Deleted PaymentMethodID: " + id.ToString() + "<br>";
                }
            }
            catch (Exception e)
            {
                lblMsg.Text += e.Message + "<br>";
            }
        }
        #endregion

        #region DeleteClient
        private void DeleteClient(int ClientID, int mid)
        {
            try
            {
                using (ClientServiceClient proxy = new ClientServiceClient("WSHttpBinding"))
                {
                    int id = proxy.deleteClient(Authenticate.GetClientAuthTicket(txtID.Text.Trim(), txtKey.Text.Trim()), mid, ClientID);
                    lblMsg.Text += "Deleted ClientID: " + id.ToString() + "<br>";
                }
            }
            catch (Exception e)
            {
                lblMsg.Text += e.Message + "<br>";
            }
        }
        #endregion

        #region GetClients
        public void GetClients(int mid)
        {
            try
            {
                using (ClientServiceClient proxy = new ClientServiceClient("WSHttpBinding"))
                {
                    int ClientID = txtClientID.Text.Trim().Length > 0 ? Convert.ToInt32(txtClientID.Text) : 0;
                    gwClient.DataSource = proxy.getClient(Authenticate.GetClientAuthTicket(txtID.Text.Trim(), txtKey.Text.Trim()), mid, ClientID);
                    gwClient.DataBind();
                }
            }
            catch (Exception e)
            {
                lblMsg.Text += e.Message + "<br>";
            }
        }
        #endregion

        #region GetPayments
        public void GetPaymentMethods(int mid)
        {
            try
            {
                using (ClientServiceClient proxy = new ClientServiceClient("WSHttpBinding"))
                {
                    int ClientID = 0;
                    if (txtClientID0.Text.Trim().Length > 0)
                        ClientID = Convert.ToInt32(txtClientID0.Text);

                    int PaymentMethodID = 0;
                    if (txtPaymentID.Text.Trim().Length > 0)
                        PaymentMethodID = Convert.ToInt32(txtPaymentID.Text);

                    gwPayment.DataSource = proxy.getPaymentMethod(Authenticate.GetClientAuthTicket(txtID.Text.Trim(), txtKey.Text.Trim()), mid, ClientID, PaymentMethodID);
                    gwPayment.DataBind();
                }
            }
            catch (Exception e)
            {
                lblMsg.Text += e.Message + "<br>";
            }
        }
        #endregion

        #region Event

        protected void btnCreateClient_Click(object sender, EventArgs e)
        {
            CreateClient(MerchantID);
        }

        protected void btnCreatePayment_Click(object sender, EventArgs e)
        {
            CreateCCPayment(Convert.ToInt32(ViewState["ClientID"]), MerchantID);
        }

        protected void btnDeleteClient_Click(object sender, EventArgs e)
        {
            DeleteClient(Convert.ToInt32(ViewState["ClientID"]), MerchantID);
        }

        protected void btnDeletePayment_Click(object sender, EventArgs e)
        {
            DeletePayment(Convert.ToInt32(ViewState["PaymentMethodID"]), MerchantID);
        }

        protected void btnUpdateClient_Click(object sender, EventArgs e)
        {
            UpdateClient(MerchantID);
        }

        protected void btnUpdatePayment_Click(object sender, EventArgs e)
        {
            UpdateCCPayment(Convert.ToInt32(ViewState["ClientID"]), MerchantID);
        }

        protected void btnCreateEC_Click(object sender, EventArgs e)
        {
            CreateECPayment(Convert.ToInt32(ViewState["ClientID"]), MerchantID);
        }

        protected void btnUpdateEc_Click(object sender, EventArgs e)
        {
            UpdateECPayment(Convert.ToInt32(ViewState["ClientID"]), MerchantID);
        }

        protected void btnGetClient_Click(object sender, EventArgs e)
        {
            GetClients(MerchantID);
        }

        protected void btnGetPayment_Click(object sender, EventArgs e)
        {
            GetPaymentMethods(MerchantID);
        }
        #endregion
        
    }
}
