﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using ServiceTestClient.TransactionService;
using System.Security.Cryptography;


namespace ServiceTestClient
{
    public partial class TestSettle : System.Web.UI.Page
    {
        protected void btnSettle_Click(object sender, EventArgs e)
        {
            DoSearch(0, Convert.ToInt32(txtPageSize.Text));
        }


        private void DoSearch(int pageIndex, int pageSize)
        {
            try
            {
                using (TransactionServiceClient proxy = new TransactionServiceClient("WSHttpBinding"))
                {
                    int TotalRecords = 0;
                    Range range = new Range();
                    range.StartDate = Convert.ToDateTime(txtStart.Text);
                    range.EndDate = Convert.ToDateTime(txtEnd.Text);

                    range.ChildMID = chkChild.Checked;
                    range.MerchantIDs = txtMID.Text;

                    Nullable<PaymentType> p = null;

                    switch (ddlPayment.SelectedValue)
                    {
                        case "CreditCard":
                            p = PaymentType.CreditCard;
                            break;
                        case "eCheck":
                            p = PaymentType.eCheck;
                            break;
                    }

                    Nullable<FundingType> f = null;

                    switch (ddlFunding.SelectedValue)
                    {
                        case "Chargeback":
                            f = FundingType.Chargeback;
                            break;
                        case "Funded":
                            f = FundingType.Funded;
                            break;
                        case "Previously Funded Reject":
                            f = FundingType.Previously_Funded_Reject;
                            break;
                        case "Rejected":
                            f = FundingType.Rejected;
                            break;
                        case "Settled":
                            f = FundingType.Settled;
                            break;
                        case "UnChargeback":
                            f = FundingType.UnChargeback;
                            break;

                    }


                    grid.DataSource = proxy.searchSettleActivity(Authenticate.GetTransactionAuthTicket(txtID.Text.Trim(), txtKey.Text.Trim()), range, p, f, pageIndex, pageSize, out TotalRecords);

                    grid.DataBind();

                    lblMsg.Text = string.Empty;
                    lblInfo.Text = "Total records count: " + TotalRecords.ToString() ;

                    if (TotalRecords > 0)
                        lblInfo.Text += "<br>Showing record#: " + (pageIndex * pageSize + 1).ToString() + " to " + ((TotalRecords < (pageIndex + 1) * pageSize) ? TotalRecords.ToString() : ((pageIndex + 1) * pageSize).ToString());

                    //show pager if TotalRecords > PageSize
                    if (TotalRecords > Convert.ToInt32(txtPageSize.Text))
                    {
                        int totalpages = TotalRecords/Convert.ToInt32(txtPageSize.Text)+1;
                        divPager.Visible = true;
                        lnkPrev.Enabled = (pageIndex > 0);
                        lnkNext.Enabled = (pageIndex < totalpages-1);
                        //load avaliable page number
                        lstPage.Items.Clear();
                        for (int i = 0; i < totalpages; i++)
                        {
                            lstPage.Items.Add(i.ToString());
                        }
                        lstPage.SelectedValue = pageIndex.ToString();

                    }
                    else
                        divPager.Visible = false;

                }
            }
            catch (Exception ex)
            {
                lblMsg.Text = ex.Message + "<br>";
                lblInfo.Text = string.Empty;
            }
        }

        #region Paging
        protected void lnkNext_Click(object sender, EventArgs e)
        {
            DoSearch(Convert.ToInt32(lstPage.SelectedValue) + 1 , Convert.ToInt32(txtPageSize.Text));
        }

        protected void lnkPrev_Click(object sender, EventArgs e)
        {
            DoSearch(Convert.ToInt32(lstPage.SelectedValue) -1, Convert.ToInt32(txtPageSize.Text));
        }

        protected void lstPage_SelectedIndexChanged(object sender, EventArgs e)
        {
            DoSearch(Convert.ToInt32(lstPage.SelectedValue), Convert.ToInt32(txtPageSize.Text));
        }
        #endregion

    }
}
