﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using ServiceTestClient.TransactionService;
using System.Text;
using System.Security.Cryptography;



namespace ServiceTestClient
{
    public partial class TestSummary : System.Web.UI.Page
    {
        protected void btnOrig_Click(object sender, EventArgs e)
        {
            ViewState["type"] = "getOriginationSummary";
            DoSearch(0, Convert.ToInt32(txtPageSize.Text));
        }


        protected void btnReceived_Click(object sender, EventArgs e)
        {
            ViewState["type"] = "getReceivedSummary";
            DoSearch(0, Convert.ToInt32(txtPageSize.Text));
        }

        protected void btnSettle_Click(object sender, EventArgs e)
        {
            ViewState["type"] = "getSettleSummary";
            DoSearch(0, Convert.ToInt32(txtPageSize.Text));
        }

        private void DoSearch(int pageIndex, int pageSize)
        {
            int TotalRecords = 0;

            grid.DataSource = CallSummaries(pageIndex, pageSize, ref TotalRecords);
            grid.DataBind();
        }

        private object CallSummaries(int pageIndex, int pageSize, ref int TotalRecords)
        {
            try
            {
                using (TransactionServiceClient proxy = new TransactionServiceClient("WSHttpBinding"))
                {
                    Range range = new Range();
                    range.StartDate = Convert.ToDateTime(txtStart.Text);
                    range.EndDate = Convert.ToDateTime(txtEnd.Text);
                    
                    range.ChildMID = chkChild.Checked;
                    range.MerchantIDs = txtMID.Text;

                    object summaries = null;

                    Authentication ticket = Authenticate.GetTransactionAuthTicket(txtID.Text.Trim(), txtKey.Text.Trim());
                    
                    if ((string)ViewState["type"] == "getSettleSummary")
                    {
                        range.EntryType = (EntryType)Enum.Parse(typeof(EntryType), ddlEntryType.SelectedValue);
                        range.TransactionType = (TransactionType)Enum.Parse(typeof(TransactionType), ddlTransType.SelectedValue);
                        summaries = proxy.getSettleSummary(ticket, range, pageIndex, pageSize, out TotalRecords);
                    }
                    else if ((string)ViewState["type"] == "getReceivedSummary")
                        summaries = proxy.getReceivedSummary(ticket, range, pageIndex, pageSize, out TotalRecords);
                    else if ((string)ViewState["type"] == "getOriginationSummary")
                        summaries = proxy.getOriginationSummary(ticket, range, pageIndex, pageSize, out TotalRecords);


                    lblMsg.Text = string.Empty;
                    lblInfo.Text = "Total records count:" + TotalRecords.ToString();

                    if (TotalRecords > 0)
                        lblInfo.Text += "<br>Showing record#: " + (pageIndex * pageSize + 1).ToString() + " to " + ((TotalRecords < (pageIndex + 1) * pageSize) ? TotalRecords.ToString() : ((pageIndex + 1) * pageSize).ToString());


                    //show pager if TotalRecords > PageSize
                    if (TotalRecords > Convert.ToInt32(txtPageSize.Text))
                    {
                        int totalpages =Convert.ToInt32(Math.Ceiling((double)TotalRecords / Convert.ToInt32(txtPageSize.Text)));
                        divPager.Visible = true;
                        lnkPrev.Enabled = (pageIndex > 0);
                        lnkNext.Enabled = (pageIndex < totalpages - 1);
                        //load avaliable page number
                        lstPage.Items.Clear();
                        for (int i = 0; i < totalpages; i++)
                        {
                            lstPage.Items.Add(i.ToString());
                        }
                        lstPage.SelectedValue = pageIndex.ToString();

                    }
                    else
                        divPager.Visible = false;

                    return summaries;
                }

            }
            catch (Exception ex)
            {
                lblMsg.Text = ex.Message + "<br>";
                lblInfo.Text = string.Empty;
                return null;
            }
        }

        #region Paging
        protected void lnkNext_Click(object sender, EventArgs e)
        {
            DoSearch(Convert.ToInt32(lstPage.SelectedValue) + 1, Convert.ToInt32(txtPageSize.Text));
        }

        protected void lnkPrev_Click(object sender, EventArgs e)
        {
            DoSearch(Convert.ToInt32(lstPage.SelectedValue) - 1, Convert.ToInt32(txtPageSize.Text));
        }

        protected void lstPage_SelectedIndexChanged(object sender, EventArgs e)
        {
            DoSearch(Convert.ToInt32(lstPage.SelectedValue), Convert.ToInt32(txtPageSize.Text));
        }
        #endregion



    }
}
